#
# spec file for package epiphany
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           epiphany
Version:        2.30.6
Release:        14.1
License:        GPLv2+
Summary:        GNOME Web Browser Based on the WebKit Rendering Engine
Url:            http://www.gnome.org/projects/epiphany/
Group:          Productivity/Networking/Web/Browsers
Source:         %{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE epiphany-hide-bookmark-editor.patch vuntz@opensuse.org -- Hide bookmark editors in menu
Patch0:         epiphany-hide-bookmark-editor.patch
# PATCH-FIX-UPSTREAM epiphany-fix-introspection-build.patch bgo#631119 vuntz@opensuse.org -- Fix build with recent g-i
Patch1:         epiphany-fix-introspection-build.patch
# PATCH-FIX-UPSTREAM epiphany-mime-scheme-handler.patch bgo#631450 vuntz@opensuse.org -- Taken from git, register http/https-related mime types
Patch2:         epiphany-mime-scheme-handler.patch
# PATCH-FEATURE-OPENSUSE epiphany-safe-one-click-install.patch bnc330070 vuntz@novell.com -- Make one-click install work with one-click
Patch6:         epiphany-safe-one-click-install.patch
# PATCH-FIX-UPSTREAM epiphany-fix-no-ca-file.patch bgo#758431 vuntz@opensuse.org -- Do not use ssl strict mode if CA file doesn't exist
Patch7:         epiphany-fix-no-ca-file.patch
BuildRequires:  NetworkManager-devel
BuildRequires:  ca-certificates
BuildRequires:  fdupes
BuildRequires:  gconf2-devel
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  gnome-icon-theme
BuildRequires:  gnome-themes
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  iso-codes-devel
BuildRequires:  libavahi-gobject-devel
BuildRequires:  libgnome-keyring-devel
BuildRequires:  libnotify-devel
BuildRequires:  libseed-devel
BuildRequires:  libsoup-devel
BuildRequires:  libwebkitgtk-devel
BuildRequires:  libxslt-devel
BuildRequires:  mozilla-nss-devel
BuildRequires:  startup-notification-devel
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
Requires:       %{name}-branding
Requires:       gnome-icon-theme
Requires:       iso-codes
Recommends:     %{name}-lang
Recommends:     ca-certificates
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%gconf_schemas_prereq

%description
Epiphany is a Web browser for the GNOME Desktop. Its principles are
simplicity and standards compliance.

%package devel
License:        GPLv2+
Summary:        GNOME Web Browser based on the WebKit Rendering Engine
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}
Requires:       gtk2-devel
Requires:       libwebkitgtk-devel
Requires:       libxml2-devel
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}

%description devel
Epiphany is a Web Browser for the GNOME Desktop. Its principles are
simplicity and standards compliance.

%package branding-upstream
License:        GPLv2+
Summary:        Upstream branding of Epiphany
Group:          Productivity/Networking/Web/Browsers
Supplements:    packageand(%{name}:branding-upstream)
Provides:       %{name}-branding = %{version}
Conflicts:      otherproviders(%{name}-branding)
#BRAND: Provide a few files -
#BRAND: /usr/share/epiphany/default-bookmarks.rdf
#BRAND:  the default bookmarks

%description branding-upstream
This package provides upstream Look and Feel for Epiphany.

%lang_package
%prep
%setup -q
translation-update-upstream
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch6 -p1
%patch7 -p1

%build
%configure \
    --disable-scrollkeeper \
    --disable-maintainer-mode \
    --enable-introspection \
    --enable-zeroconf \
    --enable-network-manager \
    --enable-seed \
    --with-distributor-name="SUSE" \
%if 0%{?suse_version} > 1120
    --with-ca-file=%{_sysconfdir}/ssl/ca-bundle.pem
%else
    --without-ca-file
%endif
%__make %{?jobs:-j%jobs}

%install
%makeinstall
%if 0%{?suse_version} <= 1110
%{__rm} %{buildroot}%{_datadir}/locale/ig/LC_MESSAGES/*
%endif
%if 0%{?suse_version} <= 1120
%{__rm} %{buildroot}%{_datadir}/locale/en@shaw/LC_MESSAGES/*
%endif
# In case make install did not create the extensions directory; note that we
# determine this directory with the pkg-config file that got installed.
extensionsdir=`pkg-config --variable extensionsdir %{buildroot}%{_libdir}/pkgconfig/epiphany-*.pc`
if ! test -d %{buildroot}${extensionsdir}; then
  install -d -m 0755 %{buildroot}${extensionsdir}
fi
%suse_update_desktop_file -N "Epiphany" %name
%suse_update_desktop_file bme
%find_lang %{name} %{?no_lang_C}
%find_gconf_schemas
%fdupes %{buildroot}

%clean
rm -rf %{buildroot}

%pre -f %{name}.schemas_pre

%post
/sbin/ldconfig
%desktop_database_post
%icon_theme_cache_post
%icon_theme_cache_post HighContrastLargePrint
%icon_theme_cache_post HighContrastLargePrintInverse

%posttrans -f %{name}.schemas_posttrans

%preun -f %{name}.schemas_preun

%postun
/sbin/ldconfig
%desktop_database_postun
%icon_theme_cache_postun
%icon_theme_cache_postun HighContrastLargePrint
%icon_theme_cache_postun HighContrastLargePrintInverse

%files -f %{name}.schemas_list
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README TODO
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%dir %{_datadir}/omf/
%dir %{_datadir}/omf/%{name}/
%doc %{_datadir}/omf/%{name}/%{name}-C.omf
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/dbus-1/services/org.gnome.Epiphany.service
%exclude %{_datadir}/epiphany/default-bookmarks.rdf
%{_datadir}/epiphany/
# When removing the HighContrastLargePrint* icon theme icons, don't forget to remove the %%icon_theme_cache_post(un) call for them
%{_datadir}/icons/HighContrastLargePrint/*/apps/*.png
%{_datadir}/icons/HighContrastLargePrintInverse/*/apps/*.png
# FIXME: gnome-themes does not provide excluded directories yet.
%exclude %{_datadir}/icons/LowContrastLargePrint/*/apps/*.png
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/*/apps/*.svg
%{_libdir}/epiphany
%{_libdir}/girepository-1.0/Epiphany-2.29.typelib
%doc %{_mandir}/man1/epiphany.1.gz

%files lang -f %{name}.lang

%files devel
%defattr(-,root,root)
%doc %{_datadir}/gtk-doc/html/epiphany/
%{_datadir}/aclocal/*.m4
%{_datadir}/gir-1.0/*.gir
%{_includedir}/epiphany*
%{_libdir}/pkgconfig/*.pc

%files branding-upstream
%defattr(-,root,root)
%{_datadir}/epiphany/default-bookmarks.rdf

%changelog
* Tue Apr 24 2012 vuntz@opensuse.org
- Add epiphany-fix-no-ca-file.patch do not use ssl strict mode in
  libsoup if CA file doesn't exist. This is needed to correctly
  work with the libsoup update for bgo#758431.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call missing relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Fri Dec 10 2010 vuntz@opensuse.org
- Add epiphany-mime-scheme-handler.patch to register the http and
  https scheme MIME types. This is needed because of a change in
  how gio works.
- Call %%desktop_database_post/%%desktop_database_postun in
  %%post/%%postun.
* Fri Oct  1 2010 vuntz@opensuse.org
- Add epiphany-fix-introspection-build.patch to fix build with
  recent version of gobject-introspection.
* Sat Sep 18 2010 vuntz@opensuse.org
- Move gir files to devel subpackage.
* Thu Sep 16 2010 vuntz@opensuse.org
- Update to version 2.30.6:
  + Do not use deprecated gdk_display
  + Do not enable maintainer mode for tarballs
* Tue Sep 14 2010 vuntz@opensuse.org
- Pass --with-distributor-name="SUSE" to configure, and remove
  lsb-release BuildRequires: it was only needed for this.
* Sat Sep  4 2010 vuntz@opensuse.org
- Add ca-certificates Recommends.
* Wed Sep  1 2010 vuntz@opensuse.org
- Update to version 2.30.5:
  + Don't depend on GTK 2.21.x.
* Mon Aug 30 2010 vuntz@opensuse.org
- Update to version 2.30.4:
  + Prevent a crasher in the download dialog
  + Highlight matches on "Find again"
  + Install introspection files in our own prefix, not g-i's
  + Fix feeds URL for relative URIs
  + Don't let ephy-favicon-cache store invalid files
  + Update libegg to latest master
  + Remove deprecated functions to work with GTK+ 2.22 / master
* Tue Aug 24 2010 vuntz@opensuse.org
- Do not call autoreconf: this is not needed anymore.
- Remove gcc-c++, gnome-common, gtk-doc BuildRequires.
- Remove gir-repository BuildRequires: not needed anymore.
- Merge doc subpackage with devel subpackage, since this is
  developer documentation.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 2.30.3:
  + bgo#624421: Adapt to GtkNotebook signal signature changes
  + Fix crash when trying to load URIs with no path
  + bgo#611400: Open URIs on new tab when middle-clicking on an
    history item
  + bgo#539716: Connect to the 'cleared' signal and change the
    sensitivity flags
  + bgo#539716: Split EphyNavigationAction in one abstract class
    and two subclasses
  + bgo#539716: Make sure WebKitWebHistory is cleared when cleared
    EphyHistory
  + bgo#136292: Send 'Referer' on headers sent for context menu
    HTTP downloads
  + bgo#611445: ephy-toolbar: fix leave-fullscreen item visibility
  + Updated translations.
- Pass --disable-maintainer-mode to configure to support building
  with gtk 2.21.6, which deprecated some more symbols.
* Sat Aug  7 2010 vuntz@opensuse.org
- Change libwebkit-devel BuildRequires (and Requires of devel
  package) to libwebkitgtk-devel, since this package got renamed.
* Mon Jun 14 2010 vuntz@opensuse.org
- Add epiphany-hide-bookmark-editor.patch to hide bme.desktop in
  the menus.
- Do not add a System category to bme.desktop.
* Thu Jun  3 2010 vuntz@opensuse.org
- Add ca-certificates BuildRequires and use --with-ca-file for
  configure on 11.3 and later, now that we have a bundle for all
  certificates.
* Fri Apr  9 2010 vuntz@opensuse.org
- When creating the extensions directory, create it with the value
  that is in epiphany's pkg-config file. This ensures we'll have
  the right directory.
- Get ready to use the certificate bundle file: we will pass
  - -with-ca-file=%%{_sysconfdir}/ssl/ca-bundle.pem to configure
  instead of --without-ca-file on 11.3 and later. This is commented
  out for now since we need a ca-certificates package that is not
  in Factory yet.
* Thu Apr  8 2010 vuntz@opensuse.org
- Update to version 2.30.2:
  + Correct extensions dir definition in lib/ too.
- Changes from version 2.30.1:
  + Improve page print implementation (bgo#609756)
  + Ignore case of URL schemes (bgo#605089)
  + Check if URL is NULL before setting its history title
    (bgo#582629)
  + Fix crasher when pressing Up arrow twice (bgo#599156)
  + Look for extensions in the correct directory, using our API
    version as versioning number.
* Tue Mar 30 2010 vuntz@opensuse.org
- Create the 2.30 extension directory, instead of 2.29. This is
  needed to fix the build of epiphany-extensions.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Fix form-based login detection in many sites (bgo#608740)
  + Make sure we show notifications in all cases for downloads
    (bgo#611635)
  + Various fixes to the migration code (bgo#608687)
* Mon Mar  8 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + bgo#610844: Fix shift+click being broken in input areas
  + bgo#610721: Always use i18n'd Desktop and Downloads dir names
* Fri Mar  5 2010 dimstar@opensuse.org
- Do not provide pixmaps/web-browser.svg; it's no longer provided
  by gnome-icon-theme.
* Thu Mar  4 2010 dimstar@opensuse.org
- Update to version 2.29.91:
  + bgo#604991: Fix window moving and resizing through DOM methods,
    a.k.a. 'Fix Browser Pong'
  + bgo#405505: Show favicons instead of radiobuttons in the tabs
    menu
  + Replace 'Enable Java' preference (which wasn't working) with a
    'Enable Plugins' preference (which works).
  + bgo#600663: Report broken SSL certs through the usual 'broken
    padlock' icon in the URL entry
  + bgo#604950: Make Ctrl+Shift+Click open links in a new window
    again
  + Lots of bugfixes and code cleanups.
- Pass --without-ca-file to configure, as we do not yet have a
  global CA store.
* Thu Feb 11 2010 vuntz@opensuse.org
- Update to version 2.29.90.1:
  + Fix crasher when storing passwords.
- Changes from version 2.29.90:
  + Remove support for XML legacy format in extensions (bgo#607881)
  + Implement EphyEmbedPersist using WebKitDownload (bgo#600987)
  + Reimplement support for cookie acceptance policies (bgo#607484)
  + Change default toolbar layout to have just one toolbar
    (bgo#412385)
  + Reimplement print preview (bgo#609021)
  + A bunch of other small bugfixes.
* Mon Jan 25 2010 captain.magnus@opensuse.org
- Update to version 2.29.6:
  + Enable the webkit page cache by default; this should give a
    noticeable to the back/forward page transition
  + Make text search more responsive by introducing a small delay
    between a key stroke and the actual search. (bgo#598322)
  + A bunch of other small bugfixes
* Wed Jan 13 2010 captain.magnus@opensuse.org
- Update to version 2.29.5:
  + Reimplement EphyEmbedSingle::handle-content signal, useful for
    external download managers
  + Add a gconf key (/apps/epiphany/general/url_search) to set the
    default search engine. (bgo#604087)
  + Reimplement favicon support (bgo#601859)
  + Do not override page specific context menus with our own
    (bgo#603326)
  + Store all form auth data in GNOME Keyring, and ask the user to
    remember and prefill new logins/passwords with an infobar.
    (bgo#582267)
  + Reimplement EphyWebView::ge-feed-link, emitted when a feed link
    is found in the view.
  + Reimplement support for the 'Accept-Language' HTTP header
    (bgo#528893)
  + Reimplement custom User Agent support, see commit e896b194fbff
    for details (bgo#580903)
  + Reimplement support for window.close (bgo#599009)
  + Reimplement support for mime type safety check during
    downloads (bgo#605026)
  + Reimplement EphyWebView::new-window signal, emitted when the
    view opens a new window (like a JS window)
  + Lots of bugfixes
- Remove epiphany-user-agent.patch. Fixed upstream
* Wed Dec 23 2009 vuntz@opensuse.org
- Change gnome-keyring-devel BuildRequires to
  libgnome-keyring-devel, following the module split upstream.
* Sat Dec  5 2009 vuntz@opensuse.org
- Update to version 2.29.3:
  + Don't assume all seed extensions return an object as a value
    (bgo#599714)
  + Fix refcounting of seed extensions (bgo#599838)
  + Provide the Inspect Element menu item in context menus again
    (bgo#599473)
  + Many fixes to our gobject-introspection support (bgo#599757)
  + Disconnect dbus callbacks when disposing of the network monitor
    (bgo#572326)
  + Only use the main frame to fetch the document type for pages
    (bgo#602400)
  + Restore 'Close' and 'Help' buttons in dialogs (bgo#590387)
  + Fix auto-google search when using Ctrl-Enter (bgo#603324)
- Changes from version 2.29.1:
  + Reimplement middle-click-to-open-clipboard-contents.
  + Reimplement traditional epiphany context menu(s). (bgo#562617)
  + Reimplement Up arrow behavior (bgo#595653)
  + Make most of epiphany compile with sealed GTK+ structs
    (bgo#595791)
  + Prevent PDM from getting keyring passwords in private mode
    (bgo#591395)
  + Take into account WEBKIT_LOAD_FAILED status for is_loading API.
  + Depend on libtool 2.2 and dump dolt.
  + Replace .glade files with .ui files natively instead of
    generating .ui files at compile time from the .glade files.
    (bgo#590387)
  + Several fixes in the automatic search of url entry contents on
    enter feature (bgo#596717, bgo#595690)
  + Use new syntax for Seed imports (bgo#598562)
  + Add back support for javascript: and mailto: URIs
  + Fix for Seed extensions preventing epiphany from shutting down
    (bgo#573551)
  + Allow popups when the user asks for them (bgo#528799)
  + Refactor EphyShell lifetime tracking (bgo#599348)
  + Don't crash when detaching multiple Seed extensions
    (bgo#599422)
  + Reimplement type checking on downloads and "Open" dialog option
    (bgo#598167)
- Rebase epiphany-user-agent.patch.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  - bgo#594435 - Fix bookmark properties rendering of multiple
    topics
  - bgo#577797 - Fix to properly get the suggested name for
    downloads in some cases
  - Strip whitespace from URIs during password migration
  - bgo#594717 - Fix crasher in profile migration
  - bgo#585499 - Append '(n)' (where n = number of duplicates) to
    duplicated downloads
  - bgo#594346 - Fix URL entry going out of sync with what is shown
    in the web view in some situations
  - bgo#594694 - Ask the user for the master password of his/her
    Gecko passwords if there was one set
  - Run mozilla-plugin-config (from nspluginwrapper) if it's
    available.
  - bgo#562611 - Implement 'Save As' for pages using
    WebKitWebDataSource
* Sun Sep 13 2009 dimstar@opensuse.org
- On openSUSE 11.1 and older the package lsb_release did not exist
  and it's content was integrated inside lsb.
- Carry the ig locale in the files list for openSUSE <= 11.1.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.92:
  + Import passwords from the gecko profile on first run. This adds
    a dependency on NSS, which can be disabled with --disable-nss
    (but then, of course, passwords won't be imported).
  + Enable undo/redo on forms (bgo#591072)
  + Save session data more often to avoid data loss when crashing
    (bgo#593149)
  + Reimplement direct search on the location bar (bgo#583795)
  + Do not save failed loads in history or show a valid security
    status for them (bgo#593200)
  + Reimplement search by just pressing '/' (bgo#587864)
  + Fix .desktop file (bgo#588979)
  + Fix warning when loading NULL URIs (bgo#593701)
  + Reimplement view source functionality (bgo#503968)
  + Show initial request before the server responds to avoid empty
    location entry (bgo#591294)
  + Reset font size with ctrl+0 from num block (bgo#573624)
  + Do not auto-shrink images, since ephy/gecko used to do that.
  + Reimplement adblock support (bgo#562762)
- Add mozilla-nss-devel BuildRequires.
- Remove sr@Latn workaround.
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 2.27.91:
  + Use new keyring support in libsoup instead of the old webkit
    session feature.
  + Performance and functionality improvements for the find
    toolbar.
  + Always show images in the bookmarks menu items. Makes them
    re-appear after recent changes that set icons off by default in
    menus for 2.28 (bgo#588563)
  + Update URL in entry when clicking on #anchors (bgo#584506)
  + Re-implement about:recover lookalike (bgo#583953)
- Use spec-cleaner to reorder lines in preamble.
* Mon Aug 10 2009 vuntz@novell.com
- Update to version 2.27.90:
  + Port PDM's password viewer to gnome-keyring so that it works
    again. (bgo#579217)
  + Fix address normalization when opening URLs from the command
    line.
  + Fix spurious whitespace when hiding downloader status
    icons. (bgo#591189)
  + Re-add the spinner so that we have some kind of progress
    notification before we receive any response from the
    server. (bgo#585035)
  + Workaround bug in WebKitGTK+ that made us never stop the
    progress notification while loading in some pages. (bgo#590170)
  + Move default bookmarks to a separate RDF file instead of
    hardcoding them. (bgo#300190)
  + Do not show about:recover URLs for now, since the service is
    not implemented. (bgo#583953)
- Add gnome-keyring-devel BuildRequires.
- Drop epiphany-bgo300190-default-bookmarks.patch: fixed upstream.
* Mon Aug  3 2009 vuntz@novell.com
- Update to version 2.27.5:
  + Use the font families set in the GNOME preferences when
    possible.
  + Fix opening multiple pages in a row from command line
    (bgo#588143)
  + Add several new mime types to the safe mime types list
    (bgo#582905, bgo#565346)
  + Fix middle click on back/forward buttons (bgo#583440)
  + Recognize favicons with mime type image/vnd.microsoft.icon.
    Keep in mind that favicons in general still do not work in
    epiphany/webkit. (bgo#578575)
- Add gir-repository, gobject-introspection-devel and libseed-devel
  BuildRequires.
- Pass --enable-introspection and --enable-seed to configure.
- Add lsb-release BuildRequires.
- Add epiphany-user-agent.patch so we can brand the user agent.
- Remove AutoReqProv from devel package: it's default now.
- Remove python-gtk, python-gnome Requires.
- Add libwebkit-devel and epiphany Requires to the devel package.
* Mon Jul 20 2009 dominique-obs@leuenberger.net
- Update to version 2.27.4:
  + Too many changes to list.
  + Epiphany now uses webkit.
- Remove now unneeded enchant-devel, gnome-desktop-devel,
  libglade2-devel, libgnomeui-devel and mozilla-xulrunner from
  BuildRequires
- Add gconf2-devel, libnotify-devel, startup-notification-devel and
  libwebkit-devel to BuildRequires.
- Remove AutoReqProv: it's default now.
- Remove obsolete --with-gecko and --enable-spell-checker from
  configure.
- Do not set categories in desktop files when they are already
  there.
- Remove part of the branding package that was specific to the
  gecko backend. This was used to set the user agent. Webkit
  doesn't support this for now, but this should be added back in
  the future.
- Update epiphany-bgo300190-default-bookmarks.patch: part of it was
  accepted upstream.
- Drop epiphany-browser-plugins.patch: WebKit does the right thing.
- Drop epiphany-libtool.patch
- Change sr@Latin to sr@latin
* Sun Mar 15 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Another NULL check for bgo#572810.
  + Try again to fix gecko 1.9.1 build. bgo#565669
  + Updated translations.
- Remove -fno-strict-aliasing from CFLAGS.
- Pass --enable-spell-checker to configure.
- Do not package omf files twice (they are in the lang package
  too).
* Tue Feb 17 2009 vuntz@novell.com
- Update to version 2.25.91:
  + Do not use 'gtk-action' object data to get the associated
    GtkAction for a widget.
  + Update EggEditableToolbar from trunk.
  + Fix build with gecko 1.9.1.
  + Add backward compat engine definition in pkg-config file.
  + Updates translations.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Feb  4 2009 vuntz@novell.com
- Reduce BuildRequires: we don't need libgnomeprintui, eg. Add
  libgnomeui-devel, though.
* Sat Jan 31 2009 mboman@suse.de
- Update to version 2.25.5:
  + Avoid adding problematic search terms with spaces
  + Handle end of line correctly on location bar search
  + Implement multiple keyword-based AND-search for the location bar
  + Include a bookmark indication in the woohoo bar
  + Turn the location bar into the woohoo bar
  + Fix bookmark import of ff3 files
  + Translation updates
* Mon Dec 29 2008 mboman@suse.de
- Update to version 2.24.2.1:
  + Fix multi-dnd with gtk 2.14
  + Fix bgo#549361
  + Translation updates
* Sat Dec 13 2008 vuntz@novell.com
- Add epiphany-safe-one-click-install.patch to make one-click
  install work. Fix bnc#330070.
* Wed Oct 22 2008 mboman@suse.de
- Update to version 2.24.1:
  + Bugs fixed: bgo#525357, bgo#535127, bgo#543335, bgo#549892, bgo#554110
    bgo#554110, bgo#555170
  + Set nsNavHistory prefs, esp. the idle update frequency to 0.
  + Use the correct return type for ephy_embed_get_link_message and
    ephy_embed_get_title
  + Translation updates
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881).
* Tue Sep 30 2008 mboman@suse.de
- Update to version 2.24.0.1:
  + Fix for GTK+ adjustment policy enforcement
  + Bugs fixed: bgo#552436, bgo#552555, bgo#550883, bgo#448613,
    bgo#426349
  + Translation updates
* Thu Sep 18 2008 maw@suse.de
- Build against mozilla-xulrunner190.
* Thu Sep 11 2008 vuntz@novell.com
- Don't put the branding files in the epiphany package too.
- .spec cleaning:
  + Correctly use packageand().
  + Remove checks from old openSUSE versions.
  + Make the spec file UTF-8.
* Wed Sep  3 2008 mboman@novell.com
- Update to version 2.23.91:
  + Remove deprecated Encoding line.
  + Remove leading dots in suggested filename. Fixes bgo#430965
  + Misc. identation fixes.
* Tue Aug 26 2008 mboman@novell.com
- Update to version 2.23.5:
  + Allow remembering the selected user cert.
  + Bug fixes: bgo#547936, bgo#151932, bgo#343906, bgo#328162,
    bgo#534218, bgo#517960
* Fri Aug  8 2008 maw@suse.de
- Update to version 2.23.5:
  + Initial release for GNOME 2.24
  + Bugs fixed (since 2.23.2): bgo#529634 and bgo#541168.
* Wed Jul 30 2008 vuntz@novell.com
- Add epiphany-bgo300190-default-bookmarks.patch to specify
  default bookmarks via a RDF file. (bgo#300190)
- Remove epiphany-default-bookmarks.patch: this will go in a
  separate branding package.
- Add epiphany-branding-upstream package.
* Fri Jul 18 2008 rodrigo@suse.de
- Fixed tagging of patches
* Wed Jun 18 2008 maw@suse.de
- Update to version 2.22.2:
  + Various bugxies
- Drop obsolete patches: epiphany-po-update.patch and
  ephy-no-cookies-selected.patch.
* Wed May 21 2008 maw@suse.de
- Use >=, not =, to require xulrunner versions (bnc#371145).
* Fri May 16 2008 maw@suse.de
- Add ephy-no-cookies-selected.patch (bgo#504136, bnc#391683).
* Wed May  7 2008 schwab@suse.de
- Create libtool before use.
* Fri May  2 2008 sbrabec@suse.cz
- Translation fix from SVN.
* Thu Apr 10 2008 maw@suse.de
- Update to version 2.22.1.1:
  + Revert the bookmark/history item no-dupes patch; it was slowing
    down ephy
  + Remove the unnecessary setting of the preferred action in the
    cases that action was going to be the default one anyway; don't
    open twice, just let gecko handle opening in the preferred
    application
  + Make the extra column pack-end so that when we hide it when
    it's empty, the other column expands; this makes bookmarks
    take up all the space instead of being truncated at the half
  + Bugs fixed:
  * Use ephy_password_info_new to allocate EphyPasswordInfo, not
    g_new; fixes a crash in the PDM passwords tab
  * Fix multiple crashers in the zeroconf bookmarks (bgo#516008)
  * Use g_slice for EphyCookie allocation (bgo#520560)
  * Use g_slice for EphyPasswordInfo, EphyPermissionInfo,
    PixbufCacheEntry (bgo#521017)
  + Updated translations
- Drop epiphany-avahi-bookmarks.patch.
* Wed Mar 26 2008 sbrabec@suse.cz
- Fixed crashes in avahi bookmarks processing (bgo#516008).
* Fri Mar 21 2008 jpr@suse.de
- Remove obsolete -devel requires
- Remove obsolete version checks
- Remove patch that was purposely disabled
- Don't create the extensions dir manually, there is a defaul plugin
  that does it for us
- Remove epiphany-desktop.patch, the GenericName is correct and there
  is no reason to hide the desktop file
- Remove 59950.diff, its obsolete by a fix in a different spot see
  bgo #165445
- Remove 59949.diff, its obsolete by a fix in a differenct spot, see
  bgo #142184
- Remove epiphany-no-root.patch, --disable-scrollkeeper works fine
  now
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Bug fixes
  + Updated translations.
* Thu Mar 13 2008 sbrabec@suse.cz
- Custom look'n'feel gconf keys moved to gconf2-branding-openSUSE.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + Bug fixes
- No longer build with the cert manager
- Remove epiphany-gcc4.3-fixes.patch.
* Tue Feb 12 2008 jpr@suse.de
- Fix missing directory ownership
- Update to use -p /sbin/ldconfig
* Fri Feb  1 2008 maw@suse.de
- Update to version 2.21.90:
  + Drop gnome-vfs in lieu of gio
  + Many bug fixes.
* Wed Nov  7 2007 maw@suse.de
- Update to version 2.20.1 (another cosmetic version bump)
- Add epiphany-gcc4.3-fixes.patch.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Mon Sep 17 2007 mauro@suse.de
- Bump version and API version to 2.20.
* Fri Aug 31 2007 maw@suse.de
- Update to version 2.19.91:
  + Compilation fixes for ancient compilers
  + Some typo changes
  + Icon reorg
  + Minor bug fixes.
* Wed Aug 22 2007 maw@suse.de
- Add default-bookmarks.patch, which adds http://news.opensuse.org
  as a default bookmark (#293690).
* Fri Aug 10 2007 coolo@suse.de
- put Version before the use of %%version
* Wed Aug  8 2007 maw@suse.de
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Thu Aug  2 2007 maw@suse.de
- Update to version 2.19.6:
  + Experimental WebKit backend [not enabled in this build]
  + New (copied) lock icons
  + Sync with latest libegg
  + New checkbox for smooth scrolling
  + Use g_get_user_special_dir to determine Desktop and Downloads
    directory locations
  + Use new gtk function to persist and load print settings and
    page setup
  + All tooltips now created using the new GTK tooltip API
  + Minor string changes
  + Bugs (bugzilla.gnome.org) fixed: 452769, 450590, 450146,
- Use %%fdupes.
* Sat Jul 14 2007 aj@suse.de
- It's really libwnck-devel.
* Mon Jul  9 2007 maw@suse.de
- Update to version 2.19.2
- Fixes for bugzilla.gnome.org #348350, #452769, #450590, #450146,
  [#346243], #351100,  #433796 , #441419, #336739, #422114, #437798,
  [#162489], and #162489
- Buildrequire libwnck-1-22-devel instead of libwnck-devel.
* Mon May 28 2007 sbrabec@suse.cz
- Update to version 2.18.1:
  * Fixed printing of frames.
  * Fixed Epiphany not finding some Gecko plugins.
- Removed Flash crash work-around (upstream part of ephy-main.c).
* Tue Apr  3 2007 maw@suse.de
- Remove all references to
  epiphany-dbus-connection-close-fix-thoenig-01.patch (#260495).
* Mon Apr  2 2007 maw@suse.de
- Update to version 2.18.0
- b.g.o 416994, 348331, 404514
- Fix several .desktop files to remove invalid Category entries.
* Mon Mar 12 2007 jhargadon@suse.de
- added gtk-doc to the BuildRequires
* Wed Jan 10 2007 sbrabec@suse.cz
- Enabled NetworkManager support.
* Wed Jan  3 2007 sbrabec@suse.cz
- Spec file cleanup.
* Fri Dec 29 2006 maw@suse.de
- Move to /usr.
* Fri Dec 29 2006 james@usr-local-bin.org
- Fix %%post.
* Thu Dec 28 2006 jhargadon@suse.de
- removed unneeded libtool file (#223685)
* Thu Nov 30 2006 sbrabec@suse.cz
- Fixed xulrunner dependencies for older products.
* Tue Nov 21 2006 jhargadon@suse.de
- re-enabled patch epiphany-browser-plugins.patch (#222861)
* Fri Nov 17 2006 thoenig@suse.de
- Add patch epiphany-dbus-connection-close-fix-thoenig-01.patch: Do
  not call dbus_connection_close on shared connection (b.n.c
  [#221827])
* Tue Nov  7 2006 sbrabec@suse.cz
- Use exact xulrunner version 181 (#216100).
* Tue Nov  7 2006 meissner@suse.de
- use RPM_OPT_FLAGS for C++ too.
* Fri Oct 13 2006 danw@suse.de
- Remove dead patches, update and reenable epiphany-desktop.patch
  and epiphany-flash-crash.patch
- Update for gnome-doc-utils-devel
* Mon Oct  2 2006 jhargadon@suse.de
- update to version 2.16.1
- Add a window group for the history window.
- Fix compile warnings
- Add smb: to recognised web schemes
- Fix spinner with new g-i-t
- Fix a crash when failing to load some icon data
* Wed Sep 13 2006 jhargadon@suse.de
- update to version 2.16.0
- Update API version for 2.16
- Add some more mime types. Fixes bug #352482
* Sat Sep  2 2006 gekker@suse.de
- Install dbus service file in correct location
* Thu Aug 24 2006 jhargadon@suse.de
- update to version 2.15.92
- translation updates
- Spell check support using the gecko 'spellchecker' extension
- Add page security info dialogue from Certificates extension
- Drop libgnomeprint[ui] and use gtk printing
- Add methods to EphyNode to set typed properties
- Add a way to turn off password remembering
- Don't crash when adding zeroconf bookmarks while bookmarks are locked
  down
- Fix middle-click and ctrl-enter in the location entry autocompletion
  drop-down
- Make the crash recovery dialog appear on the taskbar
- copy history over when opening link in new tab/win using
  context menu
- Don't crash on error from zeroconf bookmarks
- Don't set cookies from favicon downloads
- Allow cookie list to be sorted
- Fix crash when moving zoom widget on toolbar
- Display the find bar for "Find Next" and "Find Previous"
  if it wasn't visible already
- Remove Shift+Ctrl+T accelerator, it was pressed accidentally
  too often and people would lose their toolbars
* Wed Aug 16 2006 ro@suse.de
- added python-gnome-devel to BuildRequires
* Wed Aug 16 2006 cthiel@suse.de
- require python-gtk-devel instead of python-gobject2-devel
* Wed Aug 16 2006 ro@suse.de
- added python-gobject2-devel to BuildRequires
* Thu Jun 29 2006 lrupp@suse.de
- Requires: mozilla-xulrunner180 for suse_version > 1010
* Mon Mar  6 2006 sbrabec@suse.cz
- Search plugins in browser-plugins directory (#154443).
* Wed Mar  1 2006 sbrabec@suse.cz
- Updated to version 1.8.5 (fixes 150372#4).
* Mon Feb 27 2006 ro@suse.de
- added kdelibs3-devel-doc to BuildRequires
* Mon Feb 20 2006 sbrabec@suse.cz
- Enabled password manager (#150372).
* Thu Feb 16 2006 sbrabec@suse.cz
- Worked around flash plugin crash (#149062).
* Thu Feb 16 2006 stbinner@suse.de
- fix Name in .desktop file
* Sun Feb  5 2006 mls@suse.de
- added mozilla-xulrunner to BuildRequires
* Thu Feb  2 2006 sbrabec@suse.cz
- Explicitly require iso-codes (#147467).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov 30 2005 gekker@suse.de
- Update to version 1.8.3
- Remove upstreamed xulrunner patch
* Wed Nov 16 2005 sbrabec@suse.cz
- Fixed mozilla/xulrunner dependencies.
* Tue Nov 15 2005 sbrabec@suse.cz
- Removed unneeded packages for build to break build cycle.
- Enable Zeroconf support.
* Tue Nov  8 2005 sbrabec@suse.cz
- Create xulrunner default prefs.
* Mon Oct 24 2005 sbrabec@suse.cz
- Fixed extension directories.
* Mon Oct 17 2005 sbrabec@suse.cz
- Updated to version 1.8.2.
- Added xulrunner patch.
* Mon Sep  5 2005 sbrabec@suse.cz
- Updated to version 1.8.0.
* Wed Aug 24 2005 gekker@suse.de
- Updated to version 1.7.5
* Fri Aug 12 2005 sbrabec@suse.cz
- Fixed requirement to not require symbols provided only by
  mozilla-nss and mozilla-nspr packages (#98002).
* Fri Aug  5 2005 sbrabec@suse.cz
- Updated to version 1.7.3.
* Wed Aug  3 2005 sbrabec@suse.cz
- Updated to version 1.6.4.
- Turned on D-BUS support.
* Sat Mar 19 2005 clahey@suse.de
- Remove Bookmarks desktop entry.
* Wed Mar  9 2005 gekker@suse.de
- Updated to version 1.6.0 (GNOME 2.10)
* Fri Mar  4 2005 gekker@suse.de
- Updated to version 1.5.8
* Wed Feb  9 2005 hhetter@suse.de
- updated to version 1.5.6
* Mon Feb  7 2005 gekker@suse.de
- Update to 1.5.5
* Sat Feb  5 2005 meissner@suse.de
- 2 falses should be NULL
* Tue Feb  1 2005 ro@suse.de
- fix compile warning
* Fri Jan 14 2005 clahey@suse.de
- Updated to 1.5.4.
* Fri Jan 14 2005 ro@suse.de
- update to 1.4.7 to accept mozilla 1.7.5
* Wed Dec 15 2004 hvogel@suse.de
- fix desktop file
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Sun Nov  7 2004 ro@suse.de
- fix build with current intltool
* Wed Oct 27 2004 mmj@suse.de
- Locale rename no to nb
* Thu Sep 23 2004 sbrabec@suse.cz
- Fixed bad LD_LIBRARY_PATH in wrapper script (#45909).
* Fri Sep 10 2004 sbrabec@suse.cz
- Minimal patch to compile with actual version of mozilla.
* Sat Sep  4 2004 ro@suse.de
- remove epiphany.desktop in install-section, not in postinstall
* Fri Sep  3 2004 sagarwal@suse.de
- Modified the spec file to delete epiphany.desktop, web-browser.desktop
  is used for epiphany browser, and epiphany.desktop creates redundant
  menu entry.
* Mon Aug 23 2004 ro@suse.de
- backport some hunks from 1.2.7 to build with mozilla-1.7.2
* Tue Jul 20 2004 rganesan@suse.de
- Modified patch for 59950(59950.diff)
* Fri Jul 16 2004 rganesan@suse.de
-Patch for ximian bug 59949
* Fri Jul 16 2004 rganesan@suse.de
-Patch for bug 59950
* Wed Jul 14 2004 rganesan@suse.de
- patch for ximian bug 58913
* Thu Jul  1 2004 hhetter@suse.de
- set default startup page
* Wed May 26 2004 ro@suse.de
- update to 1.2.5 to build with mozilla-1.7
* Tue May 11 2004 sbrabec@suse.cz
- Added empty directories /opt/gnome/%%_lib/epiphany and
  /opt/gnome/%%_lib/epiphany/extensions to filelist.
* Fri Apr 30 2004 hhetter@suse.de
- updated to version 1.2.2 [GNOME2.6]
- seperate gtk-doc documentation package
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
* Fri Mar  5 2004 hhetter@suse.de
- suse homepage as startpage
* Fri Feb 20 2004 sbrabec@suse.cz
- Fixed names of GNOME2 packages.
* Tue Feb 17 2004 adrian@suse.de
- use Network Category, instead of Internet
* Thu Feb 12 2004 hhetter@suse.de
- gconf schema (de-)installation in %%post and %%postun
* Wed Jan 28 2004 ro@suse.de
- update to 1.0.7 to fix build with mozilla 1.6
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Nov 10 2003 hhetter@suse.de
- updated to version 1.0.6
* Thu Nov  6 2003 hhetter@suse.de
- updated to version 1.0.5
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 1.0.4.
* Fri Oct 17 2003 hhetter@suse.de
- updated to version 1.0.3
* Wed Oct 15 2003 hhetter@suse.de
- updated to version 1.0.2
- use aclocal
* Tue Sep  9 2003 hhetter@suse.de
- updated to version 1.0 (minor bugfixes and translations)
* Tue Sep  2 2003 hhetter@suse.de
- updated to version 0.9.3 (translations only)
* Mon Aug 25 2003 sbrabec@suse.cz
- Updated to version 0.9.2.
* Tue Aug 19 2003 sbrabec@suse.cz
- Updated neededforbuild (rename of librsvg2, eel2).
* Tue Aug 12 2003 adrian@suse.de
- add Categories
* Mon Aug 11 2003 hhetter@suse.de
- updated to bugfix release 0.8.4
* Mon Aug  4 2003 hhetter@suse.de
- updated to bugfix release 0.8.2
* Mon Jul 28 2003 hhetter@suse.de
- initial SuSE package
